# -*- coding: utf-8 -*-
# noinspection PyUnresolvedReferences
from loguru import logger

# noinspection PyUnresolvedReferences
from diff_1c.__about__ import __version__
# noinspection PyUnresolvedReferences
from diff_1c.main import Processor
